PurchaseEvent class

When the user successfully completes an in-app purchase

Inheritance

Constructors

PurchaseEvent()

Properties

contents List<TrackWiseContent>
getter/setter pair
eventName String
finalinherited
hashCode int
The hash code for this object.
no setterinherited
orderId String
getter/setter pair
revenue double
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited