TrackWiseContent class

Constructors

TrackWiseContent({required String contentId, String? contentName, String? currency, double price = 0.0, int quantity = 1})
const

Properties

contentId String
final
contentName String?
final
currency String?
final
hashCode int
The hash code for this object.
no setterinherited
price double
final
quantity int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited