TrackWise class abstract
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checkClipboardInfo(
) → Future< void> -
enableLog(
) → Future< void> -
getAttribution(
) → Future< TrackWiseAttribution> -
getSdkVersion(
) → Future< String> -
setCustomerUserId(
String userId) → Future< void> -
setUserInfo(
TrackWiseUserInfo userInfo) → Future< void> -
start(
TrackWiseConfig config) → Future< void> -
trackEvent(
TrackWiseEvent event) → Future< void>