TrackWiseConfig class
Constructors
- TrackWiseConfig({required String accountId, required String devToken, required String appleStoreId, String? packageSource, bool waitForCustomerUserId = false, int waitCustomerUserIdTimeoutMs = 3 * 60 * 1000, bool waitForClipboardInfo = false, int waitClipboardInfoTimeoutMs = 3 * 60 * 1000, int waitATTTimeoutMs = 3 * 60 * 1000, String? metaAppId, OnAttributionCallback? onAttributionCallback})
-
const
Properties
- accountId → String
-
final
- appleStoreId → String
-
final
- devToken → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- metaAppId → String?
-
final
- onAttributionCallback → OnAttributionCallback?
-
final
- packageSource → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- waitATTTimeoutMs → int
-
final
- waitClipboardInfoTimeoutMs → int
-
final
- waitCustomerUserIdTimeoutMs → int
-
final
- waitForClipboardInfo → bool
-
final
- waitForCustomerUserId → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited